@@ -4,12 +4,7 @@
 
 import types
 import couchdb2
-
-
-config = {
-    "TABLES": ["config", "devices", "apps", "instants", "tokens", "brain", "logs"],
-    "DATABASE": "jarvis"
-}
+from functools import wraps
 
 
 class Database:
@@ -25,7 +20,15 @@ class Database:
     def table(self, name: str, pure: bool = False):
         # A database is also a table in couchdb, so we make a trick:
         #   prefix all tables with a given database name
-        return Table(self.server, f"{self.name}-{name}") if not pure else Table(self.server, name)
+        return Table(self.server, name if pure else f"{self.name}-{name}")
+
+    def delete(self):
+        for db in self.server:
+            if str(db).startswith(f"{self.name}-"):
+                db.destroy()
+
+    def drop(self):
+        return self.delete()
 
     @property
     def up(self):
@@ -45,10 +48,10 @@ class Table:
         return self.table.get(id)
 
     def all(self) -> list:
-        doc_list = DocumentList(self)
+        all_list = DocumentList(self)
         for doc in self.table:
-            doc_list.add(doc)
-        return doc_list
+            all_list.add(dict(doc))
+        return all_list
 
     def insert(self, document: dict) -> any:
         return self.table.put(document)
@@ -60,43 +63,51 @@ class Table:
         """
         doc_list = DocumentList(self)
         if (isinstance(filter, types.LambdaType)):
-            for document in self.get_all():
+            for document in self.all():
                 if filter.__call__(document):
                     doc_list.add(document)
         if (isinstance(filter, dict)):
-            for document in self.get_all():
+            if len(filter) == 0:
+                return self.all()
+            for document in self.all():
                 for key in filter:
                     if key in document and document[key] == filter[key]:
                         doc_list.add(document)
         return doc_list
 
-    def delete(self):
-        self.table.destroy()
+    def delete(self, document):
+        self.table.purge([document])
+
+    def drop(self):
+        return self.table.destroy()
 
 
 class DocumentList:
-    def __init__(self, table: Table, document_list: list = []) -> None:
+    def __init__(self, table: Table) -> None:
         self.table = table
-        self.document_list = document_list
+        self.document_list = []
 
-    def add(self, item_or_list: any, append_lists=False):
-        if (isinstance(item_or_list, list)) and not append_lists:
-            for item in list:
-                self.add(item, True)
-        else:
-            self.document_list.append(item_or_list)
+    def add(self, item: dict) -> None:
+        self.document_list.append(item)
 
-    def update(self, new_document: dict):
+    def set(self, new_document: dict) -> None:
         for document in self.document_list:
             if "_id" not in new_document:
                 new_document["_id"] = document["_id"]
                 new_document["_rev"] = document["_rev"]
             self.table.insert(new_document)
-        pass
 
-    def delete(self):
+    def update(self, new_document: dict) -> None:
         for document in self.document_list:
-            self.table.table.delete(document)
+            def merge_dicts(x, y):
+                z = x.copy()
+                z.update(y)
+                return z
+            self.table.insert(merge_dicts(document, new_document))
+
+    def delete(self) -> None:
+        for document in self.document_list:
+            self.table.delete(document)
 
     @property
     def found(self):
@@ -104,3 +115,7 @@ class DocumentList:
 
     def __getitem__(self, key: int):
         return self.document_list[key]
+    
+    def __list__(self):
+        return self.document_list
+
