@@ -15,7 +15,6 @@ MAX_FAST_LENGTH = 1000					# 1000 entries
 
 class Logger:
     def __init__(self, referer):
-        self.db = Database()
         self.referer = referer
         self.fast = False
         self.grouping = False
@@ -95,7 +94,7 @@ class Logger:
         if self.to_console:
             print("{} - {} - {}/{}{} {}".format(str(datetime.now()), self.referer + (" " * (15-len(self.referer))), pre, tag, " " * (15-len(tag)), message))
 
-            self.db.table("logs").insert({
+            Database().table("logs").insert({
                 "timestamp": time.time(),
                 "referer": self.referer,
                 "importance": pre,
